OpenERP Proxy Modules
=====================

.. toctree::
   :maxdepth: 2

   odoo_rpc_client
   odoo_rpc_client.connection
   odoo_rpc_client.service
   odoo_rpc_client.orm
   odoo_rpc_client.plugins
